==> postgrest-0.4.2.0-18-i686.pkg.tar.xz: usr/share/haskell/register/postgrest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgrest
version: 0.4.2.0
id: postgrest-0.4.2.0-7x82DJvzF0qDxdytAUkM5y
key: postgrest-0.4.2.0-7x82DJvzF0qDxdytAUkM5y
license: MIT
maintainer: cred+github@begriffs.com
homepage: https://github.com/begriffs/postgrest
synopsis: REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for the tables and views, supporting all HTTP verbs that security
    permits.
category: Web
author: Joe Nelson, Adam Baker
exposed: True
indefinite: False
exposed-modules:
    PostgREST.ApiRequest PostgREST.App PostgREST.Auth PostgREST.Config
    PostgREST.DbRequestBuilder PostgREST.DbStructure PostgREST.Error
    PostgREST.Middleware PostgREST.OpenAPI PostgREST.Parsers
    PostgREST.QueryBuilder PostgREST.RangeQuery PostgREST.Types
hidden-modules: Paths_postgrest
abi: 8bf525d55ad203ea5b9cc688f97d6290
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/postgrest-0.4.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/postgrest-0.4.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/postgrest-0.4.2.0
hs-libraries: HSpostgrest-0.4.2.0-7x82DJvzF0qDxdytAUkM5y
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk base-4.10.0.0
    bytestring-0.10.8.2 case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    cassava-0.5.1.0-Kqu5CgeKi1R71yUdIH0q2e
    configurator-ng-0.0.0.1-ANFRGAw0gkZ9q2I19PPe0I containers-0.5.10.2
    contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe
    either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj
    hasql-0.19.18.2-EyByh1vyBAJIpCcjYoNty0
    hasql-pool-0.4.1-7bczKPc6YfOAaQ07um1BQ4
    hasql-transaction-0.5-JqHGYRf3IopGB0FJz21iNJ
    heredoc-0.2.0.0-4rbuntC2w7uF8duZNRyuy6
    HTTP-4000.3.7-Hw6XepIHeicKJxUXQPE0PZ
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    insert-ordered-containers-0.2.1.0-1BdmWkPqhCJICooGCFeGDN
    interpolatedstring-perl6-1.0.0-Cw1IZZVSwRk1W62OxNTfmy
    jwt-0.7.2-3YtiLaCTsql5dSxOuuvhfN lens-4.15.4-BVNSGosFkEc34U2t4uFumn
    lens-aeson-1.0.2-FbV1STUIE4EF7PlHDR2Ekd
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    protolude-0.2-7UgYLBOnobWCGAEKmR0pKM
    Ranged-sets-0.3.0-H6ll30XIxxaEz2mD5v3ToW
    regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    swagger2-2.1.6-HoMEdaSlhDaAtlhogramsb
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    wai-cors-0.2.5-30PEMgIj1yED2ZgmKBgce
    wai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS
    wai-middleware-static-0.8.1-5lZQxhu0s3L7dgmPoJU8m7
    cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk=dd8d552288e499e2e21b7896e82609e8
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             cassava-0.5.1.0-Kqu5CgeKi1R71yUdIH0q2e=ea71319ddd009e2ac754c872c3758507
             configurator-ng-0.0.0.1-ANFRGAw0gkZ9q2I19PPe0I=885e0168a1399bb9f9063b86125030ba
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe=6ad8f06d2a954a3785058f9dadfcb436
             either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj=9558fa760db7fa13c9efdaf91276757e
             hasql-0.19.18.2-EyByh1vyBAJIpCcjYoNty0=bf40f1ab381d98128a9c155fc288832c
             hasql-pool-0.4.1-7bczKPc6YfOAaQ07um1BQ4=68346204662bd360b7b86b2c29364b85
             hasql-transaction-0.5-JqHGYRf3IopGB0FJz21iNJ=e7421c3956d35ec9dd727a63b048913d
             heredoc-0.2.0.0-4rbuntC2w7uF8duZNRyuy6=9c4037a2dce2955b97c513dcb23709f5
             HTTP-4000.3.7-Hw6XepIHeicKJxUXQPE0PZ=b3b11e7e23a8d9c723cc7c83fcff6efd
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             insert-ordered-containers-0.2.1.0-1BdmWkPqhCJICooGCFeGDN=7418c92369a5fc7948360816186d4909
             interpolatedstring-perl6-1.0.0-Cw1IZZVSwRk1W62OxNTfmy=1bd0871b201464bba507f83ff6ab97ec
             jwt-0.7.2-3YtiLaCTsql5dSxOuuvhfN=5dd005d5a4d1def9504058a45dc4f4a8
             lens-4.15.4-BVNSGosFkEc34U2t4uFumn=693a07eed940cac4dd3dec3341ea8baa
             lens-aeson-1.0.2-FbV1STUIE4EF7PlHDR2Ekd=ba6c96a16f557d76c967968b842832cd
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=8c6e4212da58d8bc69ad7a6f814edde6
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             protolude-0.2-7UgYLBOnobWCGAEKmR0pKM=ada78bfcfeab8fe5dc441abd163c4235
             Ranged-sets-0.3.0-H6ll30XIxxaEz2mD5v3ToW=7c7311182e805afedbb7d2314e9496b4
             regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw=a4a19938ad7bbae62d09937bd32287f4
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             swagger2-2.1.6-HoMEdaSlhDaAtlhogramsb=0861b5817eff18a389f13c2f4bea8776
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             wai-cors-0.2.5-30PEMgIj1yED2ZgmKBgce=02711def417ee34ce297a6a40fe4c2f5
             wai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS=1dff1369fdaa1f0b9ddfb5c9876e47e4
             wai-middleware-static-0.8.1-5lZQxhu0s3L7dgmPoJU8m7=6c026acb4d9447b40dc797a29b1d908f
             cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc=b4cec15972259e142a0c3a4845b57827
haddock-interfaces: /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html: /usr/share/doc/postgrest/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> postgrest-0.4.2.0-19-i686.pkg.tar.xz: usr/share/haskell/register/postgrest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgrest
version: 0.4.2.0
id: postgrest-0.4.2.0-Htea6Al0oSZsDyampXlwX
key: postgrest-0.4.2.0-Htea6Al0oSZsDyampXlwX
license: MIT
maintainer: cred+github@begriffs.com
homepage: https://github.com/begriffs/postgrest
synopsis: REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for the tables and views, supporting all HTTP verbs that security
    permits.
category: Web
author: Joe Nelson, Adam Baker
exposed: True
indefinite: False
exposed-modules:
    PostgREST.ApiRequest PostgREST.App PostgREST.Auth PostgREST.Config
    PostgREST.DbRequestBuilder PostgREST.DbStructure PostgREST.Error
    PostgREST.Middleware PostgREST.OpenAPI PostgREST.Parsers
    PostgREST.QueryBuilder PostgREST.RangeQuery PostgREST.Types
hidden-modules: Paths_postgrest
abi: d15e6e9f2c290867e73b03ef3e636ef2
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/postgrest-0.4.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/postgrest-0.4.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/postgrest-0.4.2.0
hs-libraries: HSpostgrest-0.4.2.0-Htea6Al0oSZsDyampXlwX
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk base-4.10.0.0
    bytestring-0.10.8.2 case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    cassava-0.5.1.0-Kqu5CgeKi1R71yUdIH0q2e
    configurator-ng-0.0.0.1-ANFRGAw0gkZ9q2I19PPe0I containers-0.5.10.2
    contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe
    either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj
    hasql-0.19.18.2-EyByh1vyBAJIpCcjYoNty0
    hasql-pool-0.4.1-7bczKPc6YfOAaQ07um1BQ4
    hasql-transaction-0.5-JqHGYRf3IopGB0FJz21iNJ
    heredoc-0.2.0.0-4rbuntC2w7uF8duZNRyuy6
    HTTP-4000.3.7-Hw6XepIHeicKJxUXQPE0PZ
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    insert-ordered-containers-0.2.1.0-1BdmWkPqhCJICooGCFeGDN
    interpolatedstring-perl6-1.0.0-Cw1IZZVSwRk1W62OxNTfmy
    jwt-0.7.2-3YtiLaCTsql5dSxOuuvhfN lens-4.15.4-BVNSGosFkEc34U2t4uFumn
    lens-aeson-1.0.2-FbV1STUIE4EF7PlHDR2Ekd
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    protolude-0.2-7UgYLBOnobWCGAEKmR0pKM
    Ranged-sets-0.3.0-18Q2kw6A3JK2xrPwr0wdO9
    regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    swagger2-2.1.6-HoMEdaSlhDaAtlhogramsb
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    wai-cors-0.2.5-30PEMgIj1yED2ZgmKBgce
    wai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS
    wai-middleware-static-0.8.1-5lZQxhu0s3L7dgmPoJU8m7
    cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk=dd8d552288e499e2e21b7896e82609e8
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             cassava-0.5.1.0-Kqu5CgeKi1R71yUdIH0q2e=ea71319ddd009e2ac754c872c3758507
             configurator-ng-0.0.0.1-ANFRGAw0gkZ9q2I19PPe0I=885e0168a1399bb9f9063b86125030ba
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe=6ad8f06d2a954a3785058f9dadfcb436
             either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj=9558fa760db7fa13c9efdaf91276757e
             hasql-0.19.18.2-EyByh1vyBAJIpCcjYoNty0=bf40f1ab381d98128a9c155fc288832c
             hasql-pool-0.4.1-7bczKPc6YfOAaQ07um1BQ4=68346204662bd360b7b86b2c29364b85
             hasql-transaction-0.5-JqHGYRf3IopGB0FJz21iNJ=e7421c3956d35ec9dd727a63b048913d
             heredoc-0.2.0.0-4rbuntC2w7uF8duZNRyuy6=9c4037a2dce2955b97c513dcb23709f5
             HTTP-4000.3.7-Hw6XepIHeicKJxUXQPE0PZ=b3b11e7e23a8d9c723cc7c83fcff6efd
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             insert-ordered-containers-0.2.1.0-1BdmWkPqhCJICooGCFeGDN=7418c92369a5fc7948360816186d4909
             interpolatedstring-perl6-1.0.0-Cw1IZZVSwRk1W62OxNTfmy=1bd0871b201464bba507f83ff6ab97ec
             jwt-0.7.2-3YtiLaCTsql5dSxOuuvhfN=5dd005d5a4d1def9504058a45dc4f4a8
             lens-4.15.4-BVNSGosFkEc34U2t4uFumn=693a07eed940cac4dd3dec3341ea8baa
             lens-aeson-1.0.2-FbV1STUIE4EF7PlHDR2Ekd=ba6c96a16f557d76c967968b842832cd
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=8c6e4212da58d8bc69ad7a6f814edde6
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             protolude-0.2-7UgYLBOnobWCGAEKmR0pKM=ada78bfcfeab8fe5dc441abd163c4235
             Ranged-sets-0.3.0-18Q2kw6A3JK2xrPwr0wdO9=40c5572be36ddc24007eb288b828812f
             regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw=a4a19938ad7bbae62d09937bd32287f4
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             swagger2-2.1.6-HoMEdaSlhDaAtlhogramsb=0861b5817eff18a389f13c2f4bea8776
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             wai-cors-0.2.5-30PEMgIj1yED2ZgmKBgce=02711def417ee34ce297a6a40fe4c2f5
             wai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS=1dff1369fdaa1f0b9ddfb5c9876e47e4
             wai-middleware-static-0.8.1-5lZQxhu0s3L7dgmPoJU8m7=6c026acb4d9447b40dc797a29b1d908f
             cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc=b4cec15972259e142a0c3a4845b57827
haddock-interfaces: /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html: /usr/share/doc/postgrest/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
